VConsole class

Mixed-in types

Constructors

VConsole()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vConsoleFlag bool
getter/setter pairinherited

Methods

console(Object object) → dynamic
inherited
consoleClear() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

singleton vConsole
getter/setter pair