LogCategory enum

Inheritance
Available extensions

Values

state → const LogCategory

basic

const LogCategory('STATE', LogLevel.debug)
update → const LogCategory
const LogCategory('UPDATE', LogLevel.debug)
build → const LogCategory
const LogCategory('BUILD', LogLevel.debug)
layout → const LogCategory
const LogCategory('LAYOUT', LogLevel.debug)
measure → const LogCategory
const LogCategory('MEASURE', LogLevel.debug)
lifecycle → const LogCategory
const LogCategory('LIFECYCLE', LogLevel.debug)
ui → const LogCategory
const LogCategory('UI', LogLevel.debug)
screen → const LogCategory

context

const LogCategory('SCREEN', LogLevel.debug)
grid → const LogCategory
const LogCategory('GRID', LogLevel.debug)

nav-page-focus

const LogCategory('NAV', LogLevel.debug)
page → const LogCategory
const LogCategory('PAGE', LogLevel.debug)
focus → const LogCategory
const LogCategory('FOCUS', LogLevel.debug)
remote → const LogCategory
const LogCategory('REMOTE', LogLevel.debug)
network → const LogCategory

others

const LogCategory('NETWORK', LogLevel.debug)
database → const LogCategory
const LogCategory('DB', LogLevel.debug)
business → const LogCategory
const LogCategory('BIZ', LogLevel.info)
analytics → const LogCategory
const LogCategory('ANALYTICS', LogLevel.warning)
crash → const LogCategory
const LogCategory('CRASH', LogLevel.error)
general → const LogCategory
const LogCategory('GENERAL', LogLevel.info)
storage → const LogCategory
const LogCategory('STORAGE', LogLevel.debug)
performance → const LogCategory
const LogCategory('PERF', LogLevel.info)

Properties

defaultLevel LogLevel
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogCategory>
A constant List of the values in this enum, in order of their declaration.