toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  StringBuffer sb = StringBuffer('(');
  pretty(landscape, portrait, name){
    if(landscape != portrait){
      if(landscape != .0){
        sb.write(' landscape$name:$landscape');
      }
      if(portrait != .0){
        sb.write(' portrait$name:$portrait');
      }
    }else
    if(landscape == portrait && landscape != .0){
      sb.write(' $name:$portrait');
    }
  }
  pretty(landscapePercent, portraitPercent, 'Percent');
  sb.write(',');
  pretty(landscapeWpc, portraitWpc, 'Wpc');
  sb.write(',');
  pretty(landscapeHpc, portraitHpc, 'Hpc');
  sb.write(',');
  pretty(landscapePx, portraitPx, 'Px');
  sb.write(')');
  return sb.toString();
}