DIRECTION class
Constructors
- DIRECTION.from(DIRECTION_ENUM d)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sets
→ Set<
DIRECTION_ENUM> -
final
Methods
-
contains(
DIRECTION_ENUM direction) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited