Expression class

Constructors

Expression(PercentGetter percentGetter, LiteralGetter? literal)
const
Expression.literal((double, PxUnit) lt)
factory
Expression.literalGetter(LiteralGetter getter)
factory
Expression.percent(double value)
factory
Expression.percentGetter(PercentGetter getter)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
literal LiteralGetter?
final
percentGetter PercentGetter
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

horizontalHeightMergeLiteral([PxUnit? pu]) LiteralGetter
横线(纵轴)转为字面量(单位值)表示,优先转成指定单位,其次同一单位,否则转成 hpc(heightPercent)
horizontalHeightMergeLiteralExpression([PxUnit? pu]) Expression
horizontalHeightMergePercent() PercentGetter
全部转换为高度的 百分比值
looseEqual(Expression other, [Size sampleSize = const Size.square(100)]) bool
looseEqualString(Expression other, [Size sampleSize = const Size.square(100)]) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verticalWidthMergeLiteral([PxUnit? pu]) LiteralGetter
纵线(横轴)转为字面量(单位值)表示,优先转成指定单位,其次是同一单位,否则转成 wpc(widthPercent)
verticalWidthMergeLiteralExpression([PxUnit? pu]) Expression
verticalWidthMergePercent() PercentGetter
全部转换为宽度的 百分比值

Operators

operator *(Object o) → dynamic
operator +(Object o) → dynamic
operator -(Object o) → dynamic
operator /(Object o) → dynamic
operator ==(Object other) bool
The equality operator.
inherited