NamedLine class

Constructors

NamedLine({required String name, required Expression expression, Paint? paint, String? father, bool isGroup = false})
const
NamedLine.copy(NamedLine copy)
vertical 创建的是 vw horizental 创建的是 vh
factory
NamedLine.expression(Expression expression, {required String name, Size sample = const Size.square(1.0), Paint? paint, String? father})
表达式计算结果
factory
NamedLine.literal((double, PxUnit) value, {required String name, Paint? paint, String? father})
literal 和 percent 混合计算的结果值(使用expression代替) 支持 vh vw rpx 等相对单位值 以及 px 绝对值
factory
NamedLine.percent(double value, {required String name, Paint? paint, String? father})
factory
NamedLine.rename({required String rename, required NamedLine copy})
factory
NamedLine.repaint({required Paint repaint, required NamedLine copy})
factory

Properties

expression Expression
final
father String?
final
hashCode int
The hash code for this object.
no setterinherited
isGroup bool
final
name String
final
paint Paint?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeAny(double any, Size viewport) double
computeHeight(Size viewport) double
computeWidth(Size viewport) double
计算终值
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator *(Object o) → dynamic
operator +(Object o) → dynamic
operator -(Object o) → dynamic
operator /(Object o) → dynamic
operator ==(Object other) bool
The equality operator.
inherited