NamedLayerContext class abstract

Inheritance
Implemented types
Implementers

Constructors

NamedLayerContext()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
initSize Size?
getter/setter pairinherited
layers List<CPO>
no setterinherited
list ListLayerContext
no setterinherited
named NamedLayerContext
no setterinherited
namedLayers Map<String, List<CPO>>
no setter
ratioList List<RatioChangeListener>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeList List<SizeChangeListener>
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addRatioChangeListener(RatioChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME}) → void
inherited
addSizeChangeListener(SizeChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME}) → void
inherited
containsRatioChangeListener(String tag) bool
inherited
containsSizeChangeListener(String tag) bool
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyAddGroupNamedPainters(Iterable<MapEntry<String, List<CPO>>> gpainters) → void
notifyAddNamedPainter(String name, CPO painter) → void
notifyAddNamedPainters(String name, Iterable<CPO> painters) → void
notifyAddPainter(CPO painter) → void
inherited
notifyAddPainters(Iterable<CPO> painters) → void
inherited
notifyClear([Iterable<CPO>? clears]) → void
inherited
notifyGroupsClear([Iterable<String>? gclears]) → void
notifyListeners() → void
Call all the registered listeners.
inherited
notifyRatioChange(Size size, double newRatio, double? oldRatio) → void
inherited
notifyRemoveGroups(Iterable<String> gremoves) → void
notifyRemoveNamedPainter(String named, CPO painter) → void
notifyRemoveNamedPainters(String name, Iterable<CPO> painters) → void
notifyRemovePainter(CPO painter) → void
inherited
notifyRemovePainters(Iterable<CPO> painters) → void
inherited
notifySizeChange(Size newSize, Size? oldSize) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeRatioChangeListener(RatioChangeListener listener, {String name = DEFAULT_TAGNAME}) bool
inherited
removeRatioChangeTag(String tag) → void
inherited
removeSizeChangeListener(SizeChangeListener listener, {String tag = DEFAULT_TAGNAME}) bool
inherited
removeSizeChangeTag(String tag) → void
inherited
toString() String
A string representation of this object.
inherited
updateAddNamedPainter(String name, CPO painter) → void
非 notify 方式刷新(update方式刷新)
updateNamedClear(String name) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited