SimpleNamedLayerContext class
- Inheritance
-
- Mixed-in types
-
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
addRatioChangeListener(RatioChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME})
→ void
-
inherited
-
addSizeChangeListener(SizeChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME})
→ void
-
inherited
-
containsRatioChangeListener(String tag)
→ bool
-
inherited
-
containsSizeChangeListener(String tag)
→ bool
-
inherited
-
dispose()
→ void
-
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyAddGroupNamedPainters(Iterable<MapEntry<String, List<CPO>>> gpainters)
→ void
-
inherited
-
notifyAddNamedPainter(String name, CPO painter)
→ void
-
inherited
-
notifyAddNamedPainters(String name, Iterable<CPO> painters)
→ void
-
inherited
-
notifyAddPainter(CPO painter)
→ void
-
inherited
-
notifyAddPainters(Iterable<CPO> painters)
→ void
-
inherited
-
notifyClear([Iterable<CPO>? clears])
→ void
-
inherited
-
notifyGroupsClear([Iterable<String>? gclears])
→ void
-
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
notifyRatioChange(Size size, double newRatio, double? oldRatio)
→ void
-
inherited
-
notifyRemoveGroups(Iterable<String> gremoves)
→ void
-
inherited
-
notifyRemoveNamedPainter(String named, CPO painter)
→ void
-
inherited
-
notifyRemoveNamedPainters(String name, Iterable<CPO> painters)
→ void
-
inherited
-
notifyRemovePainter(CPO painter)
→ void
-
inherited
-
notifyRemovePainters(Iterable<CPO> painters)
→ void
-
inherited
-
notifySizeChange(Rect newSize, Rect? oldSize)
→ void
-
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeRatioChangeListener(RatioChangeListener listener, {String name = DEFAULT_TAGNAME})
→ bool
-
inherited
-
removeRatioChangeTag(String tag)
→ void
-
inherited
-
removeSizeChangeListener(SizeChangeListener listener, {String tag = DEFAULT_TAGNAME})
→ bool
-
inherited
-
removeSizeChangeTag(String tag)
→ void
-
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateAddNamedPainter(String name, CPO painter)
→ void
-
非 notify 方式刷新(update方式刷新)
inherited
-
updateNamedClear(String name)
→ void
-
inherited