ScreenContext class

Inheritance

Constructors

ScreenContext({RUNMODE mode = RUNMODE.debug, Size? singleAspectRatioSize, TailColumnExpand tailColumnExpand = TailColumnExpand.none, required RCPair rowColumn})
ScreenContext.fromRVG(ResponsiveValueGroup rvg)
factory

Properties

column int
no setter
consumeMeasuredCb VoidCallback?
no setter
contextScreenColorMap Map<String, Color>
getter/setter pair
contextScreenPatterns Map<int, Map<String, List<String>>>
getter/setter pair
contextScreenPatternsMap Map<int, Map<String, Map<String?, String?>>>
getter/setter pair
currentPattern String
no setter
currentPatternNullable String?
getter/setter pair
fullscreenAspectRatioSize Size?
no setter
gKeyMappedValues Map<String, GKeyValueRecord>
跟测量相关
getter/setter pair
gKeys Map<String, GlobalKey<State<StatefulWidget>>>
初始化 Key
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
initSize Size?
getter/setter pairinherited
isNeedMeasure bool
no setter
lastPattern String?
no setter
measured bool
no setter
mode RUNMODE
更改模式不引起重新布局
getter/setter pair
ratioList List<RatioChangeListener>
no setterinherited
row int
no setter
rowColumn RCPair
更改行列会导致 重新布局 gKeys.clear(); 需要测量 gKeyMappedValues.clear(); 恢复 语境初始分屏模式
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleAspectRatioSize Size?
更改屏幕比例导致 重新测量 gKeyMappedValues.clear();
getter/setter pair
singles List<String>
no setter
sizeList List<SizeChangeListener>
no setterinherited
tailColumnExpand TailColumnExpand
getter/setter pair
tailColumnExpandAvailable bool
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addRatioChangeListener(RatioChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME}) → void
inherited
addSizeChangeListener(SizeChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME}) → void
inherited
autoSetPatternByColumnNum() → void
cellRange(String screenPT) → (String, String)?
containsRatioChangeListener(String tag) bool
inherited
containsSizeChangeListener(String tag) bool
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
genContextPTColumnsLR(List<int> columnsLR) String?
genContextPTColumnsRL(List<int> columnsRL) String?
handSet(ScreenHandset setting) → void
isTailInclude(String singlePT) → dynamic
检查屏幕语境是否包含尾屏
measuredCell(int column, [int row = 1]) Rect?
measuredPT(String screenPT) Rect?
包含 cell-x-1 的情况
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
notifyRatioChange(Size size, double newRatio, double? oldRatio) → void
inherited
notifySizeChange(Size newSize, Size? oldSize) → void
inherited
offsetFromGrid({int? column, int row = 1, String? screenPT, required NamedLine vertical, required NamedLine horizontal, bool isGlobal = true}) Offset?
paintRect(String screenPT) Rect?
produceMeasuredCb(VoidCallback measuredCb) → void
rectFromGrid({int? column, int row = 1, String? screenPT, required List<NamedLine> verticals, required List<NamedLine> horizontals, bool isGlobal = true}) Rect?
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeRatioChangeListener(RatioChangeListener listener, {String name = DEFAULT_TAGNAME}) bool
inherited
removeRatioChangeTag(String tag) → void
inherited
removeSizeChangeListener(SizeChangeListener listener, {String tag = DEFAULT_TAGNAME}) bool
inherited
removeSizeChangeTag(String tag) → void
inherited
resetPattern() → void
screenPTFromColumnsLR(int column) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

columnPosFromScreenPT(String screenPT) ColumnPos?
genScreenPTColumnsLR(List<int> columnsLR, int maxColumn) List<String>?
genScreenPTColumnsRL(List<int> columnsRL, int maxColumn) List<String>?
screenPTColumnsLR(int fromStartLR, int columns) String?
screenPTColumnsRL(int fromStartRL, int columns) String?