BaseScreenContext class abstract

Inheritance
Implementers

Constructors

BaseScreenContext({RUNMODE mode = RUNMODE.debug, required Size? singleAspectRatioSize, TailColumnExpand tailColumnExpand = TailColumnExpand.none, required RCPair rowColumn, FocusPageMode focusPageMode = FocusPageMode.multiLR})

Properties

column int
no setter
columnSpanPTs List<String>
no setter
contextScreenColorMap Map<String, Color>
getter/setter pair
contextScreenPatternsMap Map<int, Map<String, Map<String?, String?>>>
用于拼画设置(把相临的两个屏幕拼合或者拆开)
getter/setter pair
currentPattern String
no setter
currentPatternNullable String?
getter/setter pair
currentRatio double?
getter/setter pairinherited
currentSize Size?
no setterinherited
currentSizeRect Rect?
getter/setter pairinherited
debug DebugToolContext?
getter/setter pair
focusPageMode FocusPageMode
getter/setter pair
fullscreenAspectRatioSize Size?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
lastPattern String?
no setter
mode RUNMODE
getter/setter pair
ratioList List<RatioChangeListener>
no setterinherited
row int
初始化 Key 跟测量相关
no setter
rowColumn RCPair
更改行列会导致 重新布局 gKeys.clear(); 需要测量 gKeyMappedValues.clear(); 恢复 语境初始分屏模式
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleAspectRatioSize Size?
更改模式不引起重新布局 更改屏幕比例导致 重新测量 gKeyMappedValues.clear();
getter/setter pair
singles List<String>
no setter
sizeList List<SizeChangeListener>
no setterinherited
tailColumnExpand TailColumnExpand
getter/setter pair
tailColumnExpandAvailable bool
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addRatioChangeListener(RatioChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME}) → void
inherited
addSizeChangeListener(SizeChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME}) → void
inherited
autoSetPatternByColumnNum() → void
cellRange(String singlePT) → (String, String)?
columnSplits(String singlePT) List<double> Function(Size size)?
根据当前 singlePT 获得 - 的分割比例,用于绘制拼屏网格线(物理拼缝,不包含在grid中)
containsRatioChangeListener(String tag) bool
inherited
containsSizeChangeListener(String tag) bool
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
genContextPTColumnsLR(List<int> columnsLR) String?
genContextPTColumnsRL(List<int> columnsRL) String?
handSet(ScreenHandset setting) → void
isTailInclude(String singlePT) → dynamic
检查屏幕语境是否包含尾屏
measuredCell(int column, [int row = 1]) Rect?
measuredPT(String singlePT) Rect?
包含 cell-x-1 的情况
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
notifyRatioChange(Size size, double newRatio, double? oldRatio) → void
inherited
notifySizeChange(Rect newSize, Rect? oldSize) → void
inherited
offsetFromGrid({int? column, int row = 1, String? singlePT, required NamedLine vertical, required NamedLine horizontal, bool isGlobal = true}) Offset?
paintRect(String singlePT) Rect?
rectFromGrid({int? column, int row = 1, String? singlePT, required List<NamedLine> verticals, required List<NamedLine> horizontals, bool isGlobal = true}) Rect?
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeRatioChangeListener(RatioChangeListener listener, {String name = DEFAULT_TAGNAME}) bool
inherited
removeRatioChangeTag(String tag) → void
inherited
removeSizeChangeListener(SizeChangeListener listener, {String tag = DEFAULT_TAGNAME}) bool
inherited
removeSizeChangeTag(String tag) → void
inherited
resetPattern() → void
screenPTFromColumnsLR(int column) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

columnPosFromScreenPT(String singlePT) ColumnPos?
combinedState(String singleOrContextPT) → (int, List<bool>)?
genScreenPTColumnsLR(List<int> columnsLR, int fromL, int maxColumn) List<String>?
genScreenPTColumnsRL(List<int> columnsRL, int maxColumn) List<String>?
ptFromState(int fromL, List<bool> combinedStates, int maxColumn) String?
screenPTColumnsLR(int fromStartLR, int columns) String?
screenPTColumnsRL(int fromStartRL, int columns) String?