ScreenContext class

Inheritance
Mixed-in types

Constructors

ScreenContext({RUNMODE mode = RUNMODE.debug, required RCPair rowColumn, Size? singleAspectRatioSize, FocusPageMode focusPageMode = FocusPageMode.multiLR, TailColumnExpand tailColumnExpand = TailColumnExpand.none})
ScreenContext.fromRVG(ResponsiveValueGroup rvg)
factory

Properties

column int
no setterinherited
columnSpanPTs List<String>
no setterinherited
contextScreenColorMap Map<String, Color>
getter/setter pairinherited
contextScreenPatternsMap Map<int, Map<String, Map<String?, String?>>>
用于拼画设置(把相临的两个屏幕拼合或者拆开)
getter/setter pairinherited
currentPattern String
no setterinherited
currentPatternNullable String?
getter/setter pairinherited
currentPatternVirtualMap Map<String, VScreenFocusPageManager>?
getter/setter pairinherited
currentRatio double?
getter/setter pairinherited
currentSize Size?
no setterinherited
currentSizeRect Rect?
getter/setter pairinherited
debug DebugToolContext?
getter/setter pairinherited
focusPageCurrentPT String?
no setterinherited
focusPageMode FocusPageMode
getter/setter pairinherited
focusPageNextIndex int
no setterinherited
focusPageNextPT String?
no setterinherited
focusPagePrevIndex int
no setterinherited
focusPagePrevPT String?
no setterinherited
fullscreenAspectRatioSize Size?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
lastPattern String?
no setterinherited
mode RUNMODE
getter/setter pairinherited
ratioList List<RatioChangeListener>
no setterinherited
row int
初始化 Key 跟测量相关
no setterinherited
rowColumn RCPair
更改行列会导致 重新布局 gKeys.clear(); 需要测量 gKeyMappedValues.clear(); 恢复 语境初始分屏模式
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleAspectRatioSize Size?
更改模式不引起重新布局 更改屏幕比例导致 重新测量 gKeyMappedValues.clear();
getter/setter pairinherited
singles List<String>
no setterinherited
sizeList List<SizeChangeListener>
no setterinherited
tailColumnExpand TailColumnExpand
getter/setter pairinherited
tailColumnExpandAvailable bool
no setterinherited
vscreenFocusCurrentIndexList List<int>
no setterinherited
vscreenFocusNextIndexList List<int>
no setterinherited
vscreenFocusPrevIndexList List<int>
参考 https://immvpc32u2.feishu.cn/docx/Bq2adq4zPo8fUSxqzzRckqb4nUP#share-MNrNdETyrokPo1xzW2lczDt8nUg
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addRatioChangeListener(RatioChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME}) → void
inherited
addSizeChangeListener(SizeChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME}) → void
inherited
autoSetPatternByColumnNum() → void
inherited
cellRange(String singlePT) → (String, String)?
inherited
columnSplits(String singlePT) List<double> Function(Size size)?
根据当前 singlePT 获得 - 的分割比例,用于绘制拼屏网格线(物理拼缝,不包含在grid中)
inherited
containsRatioChangeListener(String tag) bool
inherited
containsSizeChangeListener(String tag) bool
inherited
createVirtual(String singlePT, [ScreenParams? givenColumns]) ScreenContext
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
findVirtualScreen(String singlePT) VScreenFocusPageManager?
inherited
focusPageMultiLR() → void
inherited
focusPageNext() String?
inherited
focusPagePrev() String?
inherited
focusPageSingleLR([int? index]) String
inherited
focusPageSingleRL([int? index]) String
inherited
genContextPTColumnsLR(List<int> columnsLR) String?
inherited
genContextPTColumnsRL(List<int> columnsRL) String?
inherited
handSet(ScreenHandset setting) → void
inherited
isTailInclude(String singlePT) → dynamic
检查屏幕语境是否包含尾屏
inherited
measuredCell(int column, [int row = 1]) Rect?
inherited
measuredPT(String singlePT) Rect?
包含 cell-x-1 的情况
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
notifyRatioChange(Size size, double newRatio, double? oldRatio) → void
inherited
notifySizeChange(Rect newSize, Rect? oldSize) → void
inherited
offsetFromGrid({int? column, int row = 1, String? singlePT, required NamedLine vertical, required NamedLine horizontal, bool isGlobal = true}) Offset?
inherited
paintRect(String singlePT) Rect?
override
rectFromGrid({int? column, int row = 1, String? singlePT, required List<NamedLine> verticals, required List<NamedLine> horizontals, bool isGlobal = true}) Rect?
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeRatioChangeListener(RatioChangeListener listener, {String name = DEFAULT_TAGNAME}) bool
inherited
removeRatioChangeTag(String tag) → void
inherited
removeSizeChangeListener(SizeChangeListener listener, {String tag = DEFAULT_TAGNAME}) bool
inherited
removeSizeChangeTag(String tag) → void
inherited
resetPattern() → void
inherited
screenPTFromColumnsLR(int column) String
inherited
toString() String
A string representation of this object.
inherited
vscreenFocusPageCurrent() List<String>
inherited
vscreenFocusPageModeRecursive(FocusPageMode mode) → void
inherited
vscreenFocusPageMultiLR() → void
inherited
vscreenFocusPageNext() List<String>
inherited
vscreenFocusPagePrev() List<String>
inherited
vscreenFocusPageSingleLR() List<int>
inherited
vscreenFocusPageSingleRL() List<int>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

columnPosFromScreenPT(String singlePT) ColumnPos?
override
combinedState(String singleOrContextPT) → (int, List<bool>)?
override
genScreenPTColumnsLR(List<int> columnsLR, int fromL, int maxColumn) List<String>?
override
genScreenPTColumnsRL(List<int> columnsRL, int maxColumn) List<String>?
override
ptFromState(int fromL, List<bool> combinedStates, int maxColumn) String?
override
screenPTColumnsLR(int fromStartLR, int columns) String?
override
screenPTColumnsRL(int fromStartRL, int columns) String?
override