ScreenParams class

Constructors

ScreenParams({Size? singleAspectRatioSize, TailColumnExpand? tailColumnExpand, RCPair? rowColumn, FocusPageMode? focusPageMode})
const

Properties

focusPageMode FocusPageMode?
final
hashCode int
The hash code for this object.
no setterinherited
rowColumn RCPair?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleAspectRatioSize Size?
final
tailColumnExpand TailColumnExpand?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited