SinglePageVirtualScreenTester class
- Inheritance
-
- Mixed-in types
-
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
addRatioChangeListener(RatioChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME})
→ void
-
inherited
-
addSizeChangeListener(SizeChangeListener listener, {Size? initSize, String tag = DEFAULT_TAGNAME})
→ void
-
inherited
-
autoSetPatternByColumnNum()
→ void
-
inherited
-
cellRange(String singlePT)
→ (String, String)?
-
inherited
-
columnSplits(String singlePT)
→ List<double> Function(Size size)?
-
根据当前 singlePT 获得 - 的分割比例,用于绘制拼屏网格线(物理拼缝,不包含在grid中)
inherited
-
containsRatioChangeListener(String tag)
→ bool
-
inherited
-
containsSizeChangeListener(String tag)
→ bool
-
inherited
-
dispose()
→ void
-
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
findVirtualScreen(String singlePT)
→ VScreenFocusPageManager?
-
inherited
-
focusPageMultiLR()
→ void
-
inherited
-
focusPageNext()
→ String?
-
inherited
-
focusPagePrev()
→ String?
-
inherited
-
focusPageSingleLR([int? index])
→ String
-
inherited
-
focusPageSingleRL([int? index])
→ String
-
inherited
-
genContextPTColumnsLR(List<int> columnsLR)
→ String?
-
inherited
-
genContextPTColumnsRL(List<int> columnsRL)
→ String?
-
inherited
-
handSet(ScreenHandset setting)
→ void
-
inherited
-
isTailInclude(String singlePT)
→ dynamic
-
检查屏幕语境是否包含尾屏
inherited
-
measuredCell(int column, [int row = 1])
→ Rect?
-
inherited
-
measuredPT(String singlePT)
→ Rect?
-
包含 cell-x-1 的情况
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
notifyRatioChange(Size size, double newRatio, double? oldRatio)
→ void
-
inherited
-
notifySizeChange(Rect newSize, Rect? oldSize)
→ void
-
inherited
-
offsetFromGrid({int? column, int row = 1, String? singlePT, required NamedLine vertical, required NamedLine horizontal, bool isGlobal = true})
→ Offset?
-
inherited
-
paintRect(String singlePT)
→ Rect?
-
inherited
-
rectFromGrid({int? column, int row = 1, String? singlePT, required List<NamedLine> verticals, required List<NamedLine> horizontals, bool isGlobal = true})
→ Rect?
-
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeRatioChangeListener(RatioChangeListener listener, {String name = DEFAULT_TAGNAME})
→ bool
-
inherited
-
removeRatioChangeTag(String tag)
→ void
-
inherited
-
removeSizeChangeListener(SizeChangeListener listener, {String tag = DEFAULT_TAGNAME})
→ bool
-
inherited
-
removeSizeChangeTag(String tag)
→ void
-
inherited
-
resetPattern()
→ void
-
inherited
-
screenPTFromColumnsLR(int column)
→ String
-
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
vscreenFocusPageCurrent()
→ List<String>
-
inherited
-
vscreenFocusPageModeRecursive(FocusPageMode mode)
→ void
-
inherited
-
vscreenFocusPageMultiLR()
→ void
-
inherited
-
vscreenFocusPageNext()
→ List<String>
-
inherited
-
vscreenFocusPagePrev()
→ List<String>
-
inherited
-
vscreenFocusPageSingleLR()
→ List<int>
-
inherited
-
vscreenFocusPageSingleRL()
→ List<int>
-
inherited