NavigatorCore<T extends MultiColumns> class abstract

Mixed-in types
Implementers

Constructors

Properties

contentPageClass int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenColumn int
no setter
vConsoleFlag bool
getter/setter pairinherited

Methods

avbColsList(NavigatableList<T> nav) List<SinglenNavigatableAvbCols>
console(Object object) → dynamic
inherited
consoleClear() → void
inherited
expandCollapse(NavCtntPair<T> currentPages, int givenScreenColumn) NavCtntPair<T>?
非连续内容扩展算法 https://immvpc32u2.feishu.cn/docx/SlLddeDrJoCW9ox4igYcPNSTnSd?from=from_copylink 6月22日改为可伸展可折叠(新增折叠),可返回 null 表示不可伸缩
expandString(NavCtntPair<T> currentPages) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shift(NavCtntPair<T> currentPages, Navigatable<T> insertPage) → (NavCtntPair<T>, NavigatableList<T>)
shiftExpand(NavCtntPair<T> currentPages, Navigatable<T> insertPage) → (NavCtntPair<T>, NavigatableList<T>)
shiftExpandString(NavCtntPair<T> currentPages, Navigatable<T> insertPage) String
shiftString(NavCtntPair<T> currentPages, Navigatable<T> insertPage) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited