BasicNavigatorBuilder class abstract

Inheritance
Implementers

Constructors

BasicNavigatorBuilder({NavCtntPair<PageCache>? initPair})

Properties

cachePathPages Map<String, PageCache>?
no setter
columnsBuilder ColumnsBuilder
no setter
contentPageClass int
no setterinherited
currentCachePages List<PageCache>
no setter
currentColumnsLR List<int>
no setter
currentContextPT String?
no setter
currentNavPairList NavigatableList<PageCache>
no setter
currentPair NavCtntPair<PageCache>
no setter
currentScreenPTs List<String>?
no setter
focusedPageInfo → (int, int, PageCache)?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen ScreenContext
no setter
screenColumn int
no setteroverride
screenPTCachePageList List<(ScreenPT, Navigatable<PageCache>)>
no setter
vConsoleFlag bool
getter/setter pairinherited

Methods

adjustScreenColumnChange({String? debugInfo, AnimationController? animCtrl, bool callUpdate = true}) → void
适应屏幕栏目数调整{
adjustScreenColumnChangeWait({String? debugInfo, AnimationController? animCtrl}) → void
avbColsList(NavigatableList<PageCache> nav) List<SinglenNavigatableAvbCols>
inherited
console(Object object) → dynamic
inherited
consoleClear() → void
inherited
currentPagesUnload() → void
directGotoPage(int pageClass, int targetColumn, FocusRoutePage page, {Map<String, String>? receiveParams, String? debugInfo, AnimationController? animCtrl, bool autoExpand = true}) → void
directGotoPageWait(int pageClass, int targetColumn, FocusRoutePage page, {Map<String, String>? receiveParams, String? debugInfo, AnimationController? animCtrl, bool autoExpand = true}) → void
expandCollapse(NavCtntPair<PageCache> currentPages, int givenScreenColumn) NavCtntPair<PageCache>?
非连续内容扩展算法 https://immvpc32u2.feishu.cn/docx/SlLddeDrJoCW9ox4igYcPNSTnSd?from=from_copylink 6月22日改为可伸展可折叠(新增折叠),可返回 null 表示不可伸缩
inherited
expandString(NavCtntPair<PageCache> currentPages) String
inherited
indexedGotoPages({List<IndexedIntentPage> intentsLR = const [], List<IndexedIntentPage> intentsRL = const [], AnimationController? animCtrl, bool callUpdate = true}) → void
indexedGotoPagesWait({List<IndexedIntentPage> intentsLR = const [], List<IndexedIntentPage> intentsRL = const [], AnimationController? animCtrl}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onColumnsChange(int screenColumn) → void
onMeasured() → void
removePages(List<FocusRoutePage> pages, {AnimationController? animCtrl, bool callUpdate = true}) → void
removePagesWait(List<FocusRoutePage> pages, {AnimationController? animCtrl}) → void
shift(NavCtntPair<PageCache> currentPages, Navigatable<PageCache> insertPage) → (NavCtntPair<PageCache>, NavigatableList<PageCache>)
inherited
shiftExpand(NavCtntPair<PageCache> currentPages, Navigatable<PageCache> insertPage) → (NavCtntPair<PageCache>, NavigatableList<PageCache>)
inherited
shiftExpandString(NavCtntPair<PageCache> currentPages, Navigatable<PageCache> insertPage) String
inherited
shiftString(NavCtntPair<PageCache> currentPages, Navigatable<PageCache> insertPage) String
inherited
toString() String
A string representation of this object.
inherited
type<T>([bool includeCache = false]) List<T>
untilUpdate({String? debugInfo, String? path, VoidCallback? afterMeasured}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited