PageCache class

Mixed-in types

Constructors

PageCache({required FocusRoutePage page, String? onCreatePath, ScreenPT? screenPT})
PageCache.changePT(PageCache cache, ScreenPT screenPT)
factory
PageCache.nopathPage(FocusRoutePage page)
factory
PageCache.pathPage(String onCreatePath, FocusRoutePage page)
factory

Properties

availableColumns List<int>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
onCreatePath String?
final
page FocusRoutePage
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenPT ScreenPT?
getter/setter pair

Methods

difference(MultiColumns target) List<int>
inherited
intersection(MultiColumns target) List<int>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
union(MultiColumns target) List<int>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited