SingleRemoteChannelRPC mixin

Superclass constraints
Implemented types

Properties

channelMap Map<String, VoidRemoteCallback>
getter/setter pairinherited
channelName String
no setter
collectResponsivePointNames List<String>
no setterinherited
collectResponsivePoints List<VoidCallback>
no setterinherited
debouncer Debouncer
no setter
focusHandler FocusManager
no setter
hashCode int
The hash code for this object.
no setterinherited
isChannelConnected bool
no setterinherited
isPlayerConnected bool
no setterinherited
isRemoteEnabled bool
no setterinherited
pointIndex int
給打点命名
no setterinherited
remoteChannel → WebSocketChannel?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collectClear() → void
inherited
collectPoint(VoidCallback? callback, {String? name, VoidCallback? after, VoidCallback? before}) VoidCallback?
把交互点包裹起来做一层远程调用 10.28 修复没有透传 null 类型的问题
override
nameResponse(String name) VoidCallback?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packRCOIntoJson(String channel, dynamic object) RemoteChannelObject
inherited
pointWrappedText(String text, {bool enabled = true}) String
inherited
remoteBroadcastUnknownChannel(RemoteChannelObject data) → void
连接存在 但是不在 build 流程中 callback
override
remoteChannelClose(String channel) → void
inherited
remoteChannelListen(void onInitData(String), {Function? onError, void onDone()?, bool? cancelOnError}) → void
inherited
remoteChannelSend(String channel, dynamic object, CloseRemoteCallback callback) → void
inherited
responseCallback(dynamic name) → void
toString() String
A string representation of this object.
inherited
unpackRCOFromJson(Map<String, dynamic> json) RemoteChannelObject
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited