FocusManager mixin

Implemented types
Mixin applications

Properties

backFocusNode FocusNode?
no setter
currentFocusNode FocusNode
no setter
DEFAULT_FOCUS_NODE FocusNode
final
downFocusNode FocusNode?
no setter
enterFocusNode FocusNode?
no setter
focusNodeReuseCacheMap Map<String, FocusNode>
final
focusUpdate → void Function(VoidCallback , [String? d])
no setter
hashCode int
The hash code for this object.
no setterinherited
leftFocusNode FocusNode?
no setter
rightFocusNode FocusNode?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upFocusNode FocusNode?
no setter

Methods

buildingEnd1stStepTestNeedResetFocus([FocusNode? buildingEndFocusNode]) → void
构建过程中原本聚焦的点位没有在build中调用时启动新点位(最后在build阶段创建的点位继承该焦点)
buildingEnd2ndStepSetDefaultFocusNode(NextFocusAction? action, {void override(FocusNode building, FocusNode dflt)?}) FocusNode
buildingUpdateAddFocusNode(NextFocusAction action, String focusName, {FocusNode? father, void override(FocusNode building, FocusNode update)?}) FocusNode
findFocusManager(FindFocusPosition position) List<FocusManager>?
findFocusManagerByOrder(List<FindFocusPosition> positions) List<FocusManager>?
focusDefault({bool update = true}) FocusNode
focusNext({required NextFocusAction action, bool update = true}) FocusNode?
focusNextAcrossManager({NextFocusAction? action, List<FindFocusPosition>? positions, bool update = true}) FocusNode?
isFocused([String? name]) bool
nextFocusNode(NextFocusAction action) FocusNode?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBlur(FocusNode target) → void
override
onFocus(FocusNode target) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

activeManager FocusManager?
getter/setter pair