RemoteChannel mixin

Mixin applications

Properties

channelMap Map<String, VoidRemoteCallback>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isChannelConnected bool
no setter
isPlayerConnected bool
no setter
isRemoteEnabled bool
no setter
remoteChannel → WebSocketChannel?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packRCOIntoJson(String channel, dynamic object) RemoteChannelObject
remoteBroadcastUnknownChannel(RemoteChannelObject data) → void
remoteChannelClose(String channel) → void
remoteChannelListen(void onInitData(String), {Function? onError, void onDone()?, bool? cancelOnError}) → void
remoteChannelSend(String channel, dynamic object, CloseRemoteCallback callback) → void
toString() String
A string representation of this object.
inherited
unpackRCOFromJson(Map<String, dynamic> json) RemoteChannelObject

Operators

operator ==(Object other) bool
The equality operator.
inherited