PageLifeCycle class abstract

Implementers

Constructors

PageLifeCycle()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCreate() → void
onDestroy() → void
onMeasured(ScreenContext screen) → void
onPause() → void
onReceive(Map<String, String>? params) → void
onResume() → void
onScreenWillChange(ScreenPT willChangePT) → void
screenBuild(BuildContext context, ContextAccessor ctxAccessor, ScreenPT screenPT) List<Widget>?
toString() String
A string representation of this object.
inherited
willPlayAnimated({ScreenPT? fromPT, required ScreenPT toPT, required AnimationController animCtrl}) AnimationController

Operators

operator ==(Object other) bool
The equality operator.
inherited