SepPath class

Constructors

SepPath(String? name, PathType type)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDynamic bool
no setter
isRoot bool
no setter
isWildcard bool
no setter
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PathType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited