KetchupUIState class

Inheritance
Implemented types
Mixed-in types

Constructors

KetchupUIState()

Properties

bgLayers LayerContext
no setteroverride
context BuildContext
The location in the tree where this widget builds.
no setterinherited
fgLayers LayerContext
no setteroverride
grid GridContext
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
lastSizeRect Rect?
确保所有语境都能收到回调
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
needUpdateMeasure bool
no setter
renderTimes int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen ScreenContext
no setteroverride
screenColumn int
no setter
screenRow int
no setter
screenRowColumn RCPair
no setter
screenSingleAspectRatioSize Size?
no setter
screenTailColumnExpand TailColumnExpand
no setter
size Size
no setteroverride
update → void Function(VoidCallback p1, [String? d])
no setteroverride
widget KetchupUISized
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildDebug<P>(P object) → P
inherited
createFromScreenContextPatterns({required BuildContext context, required String screenContextPattern}) List<Widget>
createSingleColumnCells({required BuildContext context, required RCPair rowColumn, ScreenContext? core}) List<Widget>
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
debugLazyUpdate(VoidCallback callback, [String? debugInfo]) → void
inherited
debugUpdate(VoidCallback callback, [String? debugInfo]) → void
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant KetchupUISized oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
editModeGridWrapping({required Widget child, required String singlePT}) Widget
fullscreenAspectRatioRow({required Widget child, required double? fullScreenAspectRatio}) Widget
0.0.3 版本去掉缓存机制
initSizeRect() → void
initState() → void
Called when this object is inserted into the tree.
override
insideColumnExpandedAspectRatio({required Widget child, int flex = 1, double? aspectRatio}) Widget
leafContainerWrapping({Key? key, Color? editModeColor, List<Widget>? children, required String leafName, Size? literalAspectRatio, String? extra, required BuildContext context}) Widget
measureDebug<P>(P object) → P
inherited
measureUpdate(VoidCallback c, [String? d, VoidCallback? afterMeasured]) → void
measureUpdateDebug<P>(P object) → P
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifySizeRatioChange() → void
outsideRowExpandedAspectRatio({required Widget child, int flex = 1, double? aspectRatio}) Widget
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
stateDebug<P>(P object) → P
inherited
testNeedMeasure() → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateBuildDebug<P>(P object) → P
inherited
updateDebug<P>(P object) → P
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited