FractionLike class

Constructors

FractionLike(int numerator, int denominator)

Properties

denominator int
final
hashCode int
The hash code for this object.
no setterinherited
numerator int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
simplify() FractionLike
约分(返回新的简化分数)
toDouble() double
转为 double
toString() String
A string representation of this object.
override

Operators

operator *(FractionLike other) FractionLike
乘法
operator +(FractionLike other) FractionLike
加法
operator -(FractionLike other) FractionLike
减法
operator /(FractionLike other) FractionLike
除法
operator ==(Object other) bool
The equality operator.
inherited