CategoryLogger class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
d(List<LogCategory> categories, String message)
→ void
-
-
dSingle(LogCategory category, String message)
→ void
-
-
e(List<LogCategory> categories, String message, [dynamic error, StackTrace? stackTrace])
→ void
-
-
enableCategories(List<LogCategory> categories, bool enabled)
→ void
-
-
enableCategoriesOrElse({List<LogCategory>? enables, List<LogCategory>? disables})
→ void
-
-
eSingle(LogCategory category, String message, [dynamic error, StackTrace? stackTrace])
→ void
-
-
i(List<LogCategory> categories, String message)
→ void
-
-
iSingle(LogCategory category, String message)
→ void
-
-
setCategoriesLevel(List<LogCategory> categories, LogLevel level)
→ void
-
-
v(List<LogCategory> categories, String message)
→ void
-
-
vSingle(LogCategory category, String message)
→ void
-
-
w(List<LogCategory> categories, String message, [dynamic error])
→ void
-
-
wSingle(LogCategory category, String message, [dynamic error])
→ void
-