ContextAccessor class abstract
语境访问器
Constructors
Properties
- bgLayers → LayerContext
-
no setter
- fgLayers → LayerContext
-
no setter
- grid → GridContext
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screen → ScreenContext
-
no setter
- size → Size
-
no setter
- update → void Function(VoidCallback , [String? d])
-
no setter
Methods
-
lazyUpdate(
VoidCallback c, [String? d, VoidCallback? afterUpdate]) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited