ExpressionOld class
Constructors
- ExpressionOld(PercentGetter percentGetter, LiteralGetter? literal, {PxUnitVector? literalCache})
-
const
- ExpressionOld.literal((double, PxUnit) lt)
-
factory
- ExpressionOld.literalGetter(LiteralGetter getter)
-
factory
- ExpressionOld.percent(double value)
-
factory
- ExpressionOld.percentGetter(PercentGetter getter)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- literal → LiteralGetter?
-
遇到 vh+vw wpc+hpc 或者 vh+wpc vw+hpc 时启用
final
- literalCache → PxUnitVector?
-
final
- percentGetter → PercentGetter
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
horizontalHeightMergeLiteral(
[PxUnit? pu]) → LiteralGetter - 横线(纵轴)转为字面量(单位值)表示,优先转成指定单位,其次同一单位,否则转成 hpc(heightPercent)
-
horizontalHeightMergeLiteralExpression(
[PxUnit? pu]) → ExpressionOld -
horizontalHeightMergePercent(
) → PercentGetter - 全部转换为高度的 百分比值
-
looseEqual(
ExpressionOld other, [Size sampleSize = const Size.square(100)]) → bool -
looseEqualString(
ExpressionOld other, [Size sampleSize = const Size.square(100)]) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verticalWidthMergeLiteral(
[PxUnit? pu]) → LiteralGetter - 纵线(横轴)转为字面量(单位值)表示,优先转成指定单位,其次是同一单位,否则转成 wpc(widthPercent)
-
verticalWidthMergeLiteralExpression(
[PxUnit? pu]) → ExpressionOld -
verticalWidthMergePercent(
) → PercentGetter - 全部转换为宽度的 百分比值
Operators
-
operator *(
Object o) → dynamic -
operator +(
Object o) → dynamic -
operator -(
Object o) → dynamic -
operator /(
Object o) → dynamic -
operator ==(
Object other) → bool -
The equality operator.
inherited