EmptyContextAccessorImp class
- Implemented types
Constructors
- EmptyContextAccessorImp(ScreenContext screen)
Properties
- bgLayers → LayerContext
-
no setteroverride
- fgLayers → LayerContext
-
no setteroverride
- grid → GridContext
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screen ↔ ScreenContext
-
getter/setter pairoverride-getter
- size → Size
-
no setteroverride
- update → void Function(VoidCallback p1, [String? d])
-
no setteroverride
Methods
-
lazyUpdate(
VoidCallback c, [String? d, VoidCallback? updated]) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited