ResponsivePointCollector mixin
交互打点工具
- Mixin applications
Properties
-
collectResponsivePointNames
→ List<
String> -
no setter
-
collectResponsivePoints
→ List<
VoidCallback> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- pointIndex → int
-
給打点命名
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
collectClear(
) → void -
collectPoint(
VoidCallback? callback, {String? name, VoidCallback? after, VoidCallback? before}) → VoidCallback? -
nameResponse(
String name) → VoidCallback? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pointWrappedText(
String text, {bool enabled = true}) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited