FocusNode class

Inheritance
Implemented types

Constructors

FocusNode({required String name, FocusNode? father})

Properties

down FocusNode?
getter/setter pair
enter FocusNode?
getter/setter pair
father FocusNode?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isFocused bool
getter/setter pair
left FocusNode?
getter/setter pair
name String
final
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
up FocusNode?
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
blur() → void
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
focus() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onBlur(FocusNode target) → void
override
onFocus(FocusNode target) → void
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited