带有生命周期的页面
- Implemented types
- Implementers
Constructors
Properties
-
availableColumns
→ List<
int> -
no setterinherited
- backFocusNode → FocusNode?
-
no setterinherited
- currentFocusNode → FocusNode
-
no setterinherited
- DEFAULT_FOCUS_NODE → FocusNode
-
finalinherited
- downFocusNode → FocusNode?
-
no setterinherited
- enterFocusNode → FocusNode?
-
no setterinherited
-
focusNodeReuseCacheMap
→ Map<
String, FocusNode> -
finalinherited
- focusUpdate → void Function(VoidCallback , [String? d])
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- leftFocusNode → FocusNode?
-
no setterinherited
- pageScreen → ScreenContext?
-
no setter
- rightFocusNode → FocusNode?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upFocusNode → FocusNode?
-
no setterinherited
Methods
-
bgFullBuild(
BuildContext context) → List< Widget> ? -
inherited
-
buildingEnd1stStepTestNeedResetFocus(
[FocusNode? buildingEndFocusNode]) → void -
构建过程中原本聚焦的点位没有在build中调用时启动新点位(最后在build阶段创建的点位继承该焦点)
inherited
-
buildingEnd2ndStepSetDefaultFocusNode(
NextFocusAction? action, {void override(FocusNode building, FocusNode dflt)?}) → FocusNode -
inherited
-
buildingUpdateAddFocusNode(
NextFocusAction action, String focusName, {FocusNode? father, void override(FocusNode building, FocusNode update)?}) → FocusNode -
inherited
-
columnsBuild(
BuildContext context, ContextAccessor ctxAccessor, ScreenPT screenPT) → List< Widget> ? -
inherited
-
difference(
MultiColumns target) → List< int> -
inherited
-
fgFullBuild(
BuildContext context) → List< Widget> ? -
inherited
-
findFocusManager(
FindFocusPosition position) → List< FocusManager> ? -
inherited
-
findFocusManagerByOrder(
List< FindFocusPosition> positions) → List<FocusManager> ? -
inherited
-
focusDefault(
{bool update = true}) → FocusNode -
inherited
-
focusNext(
{required NextFocusAction action, bool update = true}) → FocusNode? -
inherited
-
focusNextAcrossManager(
{NextFocusAction? action, List< FindFocusPosition> ? positions, bool update = true}) → FocusNode? -
inherited
-
intersection(
MultiColumns target) → List< int> -
inherited
-
isFocused(
[String? name]) → bool -
inherited
-
nextFocusNode(
NextFocusAction action) → FocusNode? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onBlur(
FocusNode target) → void -
inherited
-
onCreate(
) → void -
inherited
-
onDestroy(
) → void -
inherited
-
onFocus(
FocusNode target) → void -
inherited
-
onMeasured(
ScreenContext screen) → void -
inherited
-
onPause(
) → void -
inherited
-
onReceive(
Map< String, String> ? params) → void -
inherited
-
onResume(
) → void -
inherited
-
onScreenWillChange(
ScreenPT willChangePT) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
union(
MultiColumns target) → List< int> -
inherited
-
willPlayAnimated(
{ScreenPT? fromPT, required ScreenPT toPT, required AnimationController animCtrl}) → AnimationController -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited